@@ -20,10 +20,10 @@ import re
 from enum import Enum, unique
 
 from liquidctl.driver.usb import UsbHidDriver
+from liquidctl.error import NotSupportedByDevice
 from liquidctl.keyval import RuntimeStorage
-from liquidctl.pmbus import compute_pec
 from liquidctl.util import RelaxedNamesEnum, clamp, fraction_of_byte, \
-                           u16le_from, normalize_profile
+                           u16le_from, normalize_profile, mkCrcFun
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -111,20 +111,20 @@ def _quoted(*names):
 class HydroPlatinum(UsbHidDriver):
     """Corsair Hydro Platinum or Pro XT liquid cooler."""
 
-    SUPPORTED_DEVICES = [
-        (0x1b1c, 0x0c18, None, 'Corsair Hydro H100i Platinum',
+    _MATCHES = [
+        (0x1b1c, 0x0c18, 'Corsair Hydro H100i Platinum',
             {'fan_count': 2, 'fan_leds': 4}),
-        (0x1b1c, 0x0c19, None, 'Corsair Hydro H100i Platinum SE',
+        (0x1b1c, 0x0c19, 'Corsair Hydro H100i Platinum SE',
             {'fan_count': 2, 'fan_leds': 16}),
-        (0x1b1c, 0x0c17, None, 'Corsair Hydro H115i Platinum',
+        (0x1b1c, 0x0c17, 'Corsair Hydro H115i Platinum',
             {'fan_count': 2, 'fan_leds': 4}),
-        (0x1b1c, 0x0c29, None, 'Corsair Hydro H60i Pro XT',
+        (0x1b1c, 0x0c29, 'Corsair Hydro H60i Pro XT',
             {'fan_count': 2, 'fan_leds': 0}),
-        (0x1b1c, 0x0c20, None, 'Corsair Hydro H100i Pro XT',
+        (0x1b1c, 0x0c20, 'Corsair Hydro H100i Pro XT',
             {'fan_count': 2, 'fan_leds': 0}),
-        (0x1b1c, 0x0c21, None, 'Corsair Hydro H115i Pro XT',
+        (0x1b1c, 0x0c21, 'Corsair Hydro H115i Pro XT',
             {'fan_count': 2, 'fan_leds': 0}),
-        (0x1b1c, 0x0c22, None, 'Corsair Hydro H150i Pro XT',
+        (0x1b1c, 0x0c22, 'Corsair Hydro H150i Pro XT',
             {'fan_count': 3, 'fan_leds': 0}),
     ]
 
@@ -137,7 +137,7 @@ class HydroPlatinum(UsbHidDriver):
         # presence of "Hydro", for backward compatibility with 1.5.0 and
         # previous versions
 
-        for vid, pid, _, desc, devargs in cls.SUPPORTED_DEVICES:
+        for vid, pid, desc, devargs in cls._MATCHES:
             if (vendor and vendor != vid) or handle.vendor_id != vid:
                 continue
             if (product and product != pid) or handle.product_id != pid:
@@ -374,11 +374,11 @@ class HydroPlatinum(UsbHidDriver):
             start_at = 3
         if data:
             buf[start_at: start_at + len(data)] = data
-        buf[-1] = compute_pec(buf[2:-1])
+        buf[-1] = mkCrcFun('crc-8')(buf[2:-1])
         self.device.clear_enqueued_reports()
         self.device.write(buf)
         buf = bytes(self.device.read(_REPORT_LENGTH))
-        if compute_pec(buf[1:]):
+        if mkCrcFun('crc-8')(buf[1:]):
             _LOGGER.warning('response checksum does not match data')
         return buf
 
@@ -420,3 +420,7 @@ class HydroPlatinum(UsbHidDriver):
             self._send_command(_FEATURE_COOLING2, _CMD_SET_COOLING, data=data2)
 
         return self._send_command(_FEATURE_COOLING, _CMD_SET_COOLING, data=data)
+
+    def set_screen(self, channel, mode, value, **kwargs):
+        """Not supported by this device."""
+        raise NotSupportedByDevice()
