@@ -198,6 +198,10 @@ class _BaseSmartDevice(UsbHidDriver):
     def _write_fixed_duty(self, cid, duty):
         raise NotImplementedError()
 
+    def set_screen(self, channel, mode, value, **kwargs):
+        """Not supported by this device."""
+        raise NotSupportedByDevice()
+
 
 class SmartDevice(_BaseSmartDevice):
     """NZXT Smart Device (V1) or Grid+ V3."""
@@ -205,12 +209,12 @@ class SmartDevice(_BaseSmartDevice):
     # support for hwmon: nzxt-grid3, liquidtux
     # https://github.com/liquidctl/liquidtux/blob/3b80dafead6f/nzxt-grid3.c
 
-    SUPPORTED_DEVICES = [
-        (0x1e71, 0x1714, None, 'NZXT Smart Device (V1)', {
+    _MATCHES = [
+        (0x1e71, 0x1714, 'NZXT Smart Device (V1)', {
             'speed_channel_count': 3,
             'color_channel_count': 1
         }),
-        (0x1e71, 0x1711, None, 'NZXT Grid+ V3', {
+        (0x1e71, 0x1711, 'NZXT Grid+ V3', {
             'speed_channel_count': 6,
             'color_channel_count': 0
         }),
@@ -275,11 +279,11 @@ class SmartDevice(_BaseSmartDevice):
 
         if self._hwmon and not direct_access:
             _LOGGER.info('bound to %s kernel driver, assuming it is already initialized',
-                         self._hwmon.module)
+                         self._hwmon.driver)
         else:
             if self._hwmon:
                 _LOGGER.warning('forcing re-initialization despite %s kernel driver',
-                                self._hwmon.module)
+                                self._hwmon.driver)
             self._write([0x1, 0x5c])  # initialize/detect connected devices and their type
             self._write([0x1, 0x5d])  # start reporting
             self.device.clear_enqueued_reports()
@@ -339,10 +343,10 @@ class SmartDevice(_BaseSmartDevice):
 
         for i in range(len(self._speed_channels)):
             n = i + 1
-            ret.append((f'Fan {n} speed', self._hwmon.get_int(f'fan{n}_input'), 'rpm')),
-            ret.append((f'Fan {n} voltage', self._hwmon.get_int(f'in{i}_input') * 1e-3, 'V')),
-            ret.append((f'Fan {n} current', self._hwmon.get_int(f'curr{n}_input') * 1e-3, 'A')),
-            ret.append((f'Fan {n} control mode', mode[self._hwmon.get_int(f'pwm{n}_mode')], '')),
+            ret.append((f'Fan {n} speed', self._hwmon.read_int(f'fan{n}_input'), 'rpm')),
+            ret.append((f'Fan {n} voltage', self._hwmon.read_int(f'in{i}_input') * 1e-3, 'V')),
+            ret.append((f'Fan {n} current', self._hwmon.read_int(f'curr{n}_input') * 1e-3, 'A')),
+            ret.append((f'Fan {n} control mode', mode[self._hwmon.read_int(f'pwm{n}_mode')], '')),
 
         # noise level is not available through hwmon, but also not very accurate or useful
 
@@ -355,12 +359,12 @@ class SmartDevice(_BaseSmartDevice):
         """
 
         if self._hwmon and not direct_access:
-            _LOGGER.info('bound to %s kernel driver, reading status from hwmon', self._hwmon.module)
+            _LOGGER.info('bound to %s kernel driver, reading status from hwmon', self._hwmon.driver)
             return self._get_status_from_hwmon()
 
         if self._hwmon:
             _LOGGER.warning('directly reading the status despite %s kernel driver',
-                            self._hwmon.module)
+                            self._hwmon.driver)
 
         return self._get_status_directly()
 
@@ -391,36 +395,40 @@ class SmartDevice2(_BaseSmartDevice):
 
     # support for hwmon: nzxt-smart2, Linux 5.17
 
-    SUPPORTED_DEVICES = [
-        (0x1e71, 0x2006, None, 'NZXT Smart Device V2', {
+    _MATCHES = [
+        (0x1e71, 0x2006, 'NZXT Smart Device V2', {
             'speed_channel_count': 3,
             'color_channel_count': 2
         }),
-        (0x1e71, 0x200d, None, 'NZXT Smart Device V2', {
+        (0x1e71, 0x200d, 'NZXT Smart Device V2', {
             'speed_channel_count': 3,
             'color_channel_count': 2
         }),
-        (0x1e71, 0x200f, None, 'NZXT Smart Device V2', {
+        (0x1e71, 0x200f, 'NZXT Smart Device V2', {
             'speed_channel_count': 3,
             'color_channel_count': 2
         }),
-        (0x1e71, 0x2001, None, 'NZXT HUE 2', {
+        (0x1e71, 0x2001, 'NZXT HUE 2', {
             'speed_channel_count': 0,
             'color_channel_count': 4
         }),
-        (0x1e71, 0x2002, None, 'NZXT HUE 2 Ambient', {
+        (0x1e71, 0x2002, 'NZXT HUE 2 Ambient', {
             'speed_channel_count': 0,
             'color_channel_count': 2
         }),
-        (0x1e71, 0x2009, None, 'NZXT RGB & Fan Controller', {
+        (0x1e71, 0x2009, 'NZXT RGB & Fan Controller', {
             'speed_channel_count': 3,
             'color_channel_count': 2
         }),
-        (0x1e71, 0x200e, None, 'NZXT RGB & Fan Controller', {
+        (0x1e71, 0x200e, 'NZXT RGB & Fan Controller', {
             'speed_channel_count': 3,
             'color_channel_count': 2
         }),
-        (0x1e71, 0x2010, None, 'NZXT RGB & Fan Controller', {
+        (0x1e71, 0x2010, 'NZXT RGB & Fan Controller', {
+            'speed_channel_count': 3,
+            'color_channel_count': 2
+        }),
+        (0x1e71, 0x2019, 'NZXT RGB & Fan Controller', {
             'speed_channel_count': 3,
             'color_channel_count': 2
         }),
@@ -506,11 +514,11 @@ class SmartDevice2(_BaseSmartDevice):
         if self._speed_channels:
             if self._hwmon and not direct_access:
                 _LOGGER.info('bound to %s kernel driver, assuming it is already initialized',
-                             self._hwmon.module)
+                             self._hwmon.driver)
             else:
                 if self._hwmon:
                     _LOGGER.warning('forcing re-initialization despite %s kernel driver',
-                                    self._hwmon.module)
+                                    self._hwmon.driver)
                 update_interval = (lambda secs: 1 + round((secs - .5) / .25))(.5)  # see issue #128
                 self._write([0x60, 0x02, 0x01, 0xe8, update_interval, 0x01, 0xe8, update_interval])
                 self._write([0x60, 0x03])
@@ -568,9 +576,9 @@ class SmartDevice2(_BaseSmartDevice):
         modes = ['DC', 'PWM']
 
         for n in range(1, len(self._speed_channels) + 1):
-            ret.append((f'Fan {n} speed', self._hwmon.get_int(f'fan{n}_input'), 'rpm')),
-            ret.append((f'Fan {n} duty', self._hwmon.get_int(f'pwm{n}') * 100. / 255, '%')),
-            ret.append((f'Fan {n} control mode', modes[self._hwmon.get_int(f'pwm{n}_mode')], '')),
+            ret.append((f'Fan {n} speed', self._hwmon.read_int(f'fan{n}_input'), 'rpm')),
+            ret.append((f'Fan {n} duty', self._hwmon.read_int(f'pwm{n}') * 100. / 255, '%')),
+            ret.append((f'Fan {n} control mode', modes[self._hwmon.read_int(f'pwm{n}_mode')], '')),
 
         # noise level is not available through hwmon, but also not very accurate or useful
 
@@ -586,12 +594,12 @@ class SmartDevice2(_BaseSmartDevice):
             return []
 
         if self._hwmon and not direct_access:
-            _LOGGER.info('bound to %s kernel driver, reading status from hwmon', self._hwmon.module)
+            _LOGGER.info('bound to %s kernel driver, reading status from hwmon', self._hwmon.driver)
             return self._get_status_from_hwmon()
 
         if self._hwmon:
             _LOGGER.warning('directly reading the status despite %s kernel driver',
-                            self._hwmon.module)
+                            self._hwmon.driver)
 
         return self._get_status_directly()
 
@@ -651,8 +659,8 @@ class SmartDevice2(_BaseSmartDevice):
 
 
 class H1V2(SmartDevice2):
-    SUPPORTED_DEVICES = [
-        (0x1e71, 0x2015, None, 'NZXT H1 V2 (experimental)', {
+    _MATCHES = [
+        (0x1e71, 0x2015, 'NZXT H1 V2 (experimental)', {
             'speed_channel_count': 2,
             'color_channel_count': 0
         }),
