@@ -1,6 +1,6 @@
 """Assorted utilities used by drivers and the CLI.
 
-Copyright (C) 2018–2021  Jonas Malaco and contributors
+Copyright (C) 2018–2022  Jonas Malaco and contributors
 SPDX-License-Identifier: GPL-3.0-or-later
 """
 
@@ -8,6 +8,9 @@ import colorsys
 import logging
 from ast import literal_eval
 from enum import Enum, EnumMeta, unique
+from functools import lru_cache
+
+import crcmod.predefined
 
 from liquidctl.error import UnsafeFeaturesNotEnabled
 
@@ -399,3 +402,19 @@ def map_direction(direction, forward=None, backward=None):
         return backward
     else:
         raise ValueError(f'invalid direction: {direction!r}')
+
+
+@lru_cache(maxsize=None)
+def mkCrcFun(crc_name):
+    """Efficiently construct a predefined CRC function.
+
+    Unstable.
+
+    For the available algorithms, see
+    <http://crcmod.sourceforge.net/crcmod.predefined.html#predefined-crc-algorithms>.
+
+    This function implements memoization, only constructing each requested CRC
+    algorithm implementation once.
+    """
+
+    return crcmod.predefined.mkCrcFun(crc_name)
